@@ -36,6 +36,8 @@
 #include <gpgme++/key.h>
 #include <gpgme++/keylistresult.h>
 
+#include <gpgme.h>
+
 #include <QDebug>
 #include <QTest>
 
@@ -47,6 +49,11 @@ Q_DECLARE_METATYPE(MessageCore::AttachmentPart)
 
 QTEST_MAIN(CryptoComposerTest)
 
+void CryptoComposerTest::initMain()
+{
+    gpgme_check_version(nullptr);
+}
+
 void CryptoComposerTest::initTestCase()
 {
     MessageComposer::Test::setupEnv();
@@ -613,8 +620,6 @@ void CryptoComposerTest::testSetGnupgHome()
     QFETCH(QString, data);
     QFETCH(bool, sign);
 
-    QSKIP("FIXME: Failing for too long");
-
     bool encrypt(true);
 
     KMime::Message::Ptr message;
