@@ -32,8 +32,8 @@ void SinglepartJobTest::testContent()
     result->assemble();
     qDebug() << result->encodedContent();
     QCOMPARE(result->body(), data);
-    QVERIFY(result->contentDisposition(false) == nullptr); // Not created unless demanded.
-    QVERIFY(result->contentType(false) == nullptr); // Not created unless demanded.
+    QCOMPARE(result->contentDisposition(false), nullptr); // Not created unless demanded.
+    QCOMPARE(result->contentType(false), nullptr); // Not created unless demanded.
     QVERIFY(result->contentTransferEncoding(false)); // KMime gives it a default one (7bit).
     delete cjob;
 }
@@ -71,8 +71,8 @@ void SinglepartJobTest::testContentID()
     result->assemble();
     qDebug() << result->encodedContent();
     QCOMPARE(result->body(), data);
-    QVERIFY(result->header<Headers::ContentID>());
-    QCOMPARE(result->header<Headers::ContentID>()->identifier(), id);
+    QVERIFY(result->contentID(false));
+    QCOMPARE(result->contentID(false)->identifier(), id);
     delete cjob;
 }
 
