@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -19,7 +19,7 @@ class MESSAGECOMPOSER_EXPORT SendLaterInfo
 public:
     explicit SendLaterInfo() = default;
 
-    enum RecurrenceUnit {
+    enum RecurrenceUnit : uint8_t {
         Days = 0,
         Weeks,
         Months,
