@@ -43,7 +43,7 @@ public:
     /**
      * Destroys the attachment part.
      */
-    virtual ~AttachmentPart();
+    ~AttachmentPart();
 
     /**
      * Sets the @p name of the attachment.
@@ -187,8 +187,6 @@ public:
     void setUrl(const QUrl &url);
     [[nodiscard]] QUrl url() const;
 
-    size_t qHash(const QSharedPointer<MessageCore::AttachmentPart> &, size_t seed = 0);
-
 private:
     //@cond PRIVATE
     class AttachmentPartPrivate;
