@@ -3,6 +3,8 @@
    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 #include "quotehtmltest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "../plugins/quotehtml.h"
 #include "setupenv.h"
 #include "util.h"
@@ -105,8 +107,8 @@ protected:
 void QuoteHtmlTest::initTestCase()
 {
     MessageViewer::Test::setupEnv();
-    mCollapseIcon = MessageViewer::IconNameCache::instance()->iconPathFromLocal(QStringLiteral("quotecollapse.png"));
-    mExpandIcon = MessageViewer::IconNameCache::instance()->iconPathFromLocal(QStringLiteral("quoteexpand.png"));
+    mCollapseIcon = MessageViewer::IconNameCache::instance()->iconPathFromLocal(u"quotecollapse.png"_s);
+    mExpandIcon = MessageViewer::IconNameCache::instance()->iconPathFromLocal(u"quoteexpand.png"_s);
 }
 
 void QuoteHtmlTest::testQuoteHtml_data()
@@ -116,29 +118,29 @@ void QuoteHtmlTest::testQuoteHtml_data()
     QTest::addColumn<bool>("showExpandQuotesMark");
     QTest::addColumn<int>("quotelevel");
     // No Expand Quotes
-    QTest::newRow("simpletext") << QStringLiteral("http") << QStringLiteral("<div class=\"noquote\"><div dir=\"ltr\">http</div></div>") << false << 1;
+    QTest::newRow("simpletext") << u"http"_s << u"<div class=\"noquote\"><div dir=\"ltr\">http</div></div>"_s << false << 1;
     QTest::newRow("simplequote") << QStringLiteral(
-        ">") << QStringLiteral("<blockquote><div class=\"quotelevel1\"><div dir=\"ltr\"><span class=\"quotemarksemptyline\">></span></div></div></blockquote>")
+        ">") << u"<blockquote><div class=\"quotelevel1\"><div dir=\"ltr\"><span class=\"quotemarksemptyline\">></span></div></div></blockquote>"_s
                                  << false << 1;
-    QTest::newRow("doublequotewithtext") << QStringLiteral(">> sddf")
+    QTest::newRow("doublequotewithtext") << u">> sddf"_s
                                          << QStringLiteral(
                                                 "<blockquote><blockquote><div class=\"quotelevel2\"><div dir=\"ltr\"><span class=\"quotemarks\">>>"
                                                 "</span><font color=\"#007000\">&nbsp;sddf</font></div></div></blockquote></blockquote>")
                                          << false << 1;
-    QTest::newRow("doublequote") << QStringLiteral(">>")
+    QTest::newRow("doublequote") << u">>"_s
                                  << QStringLiteral(
                                         "<blockquote><blockquote><div class=\"quotelevel2\"><div dir=\"ltr\"><span "
                                         "class=\"quotemarksemptyline\">>></span></div></div></blockquote></blockquote>")
                                  << false << 1;
-    QTest::newRow("simplespace") << QStringLiteral(" ") << QStringLiteral("<div class=\"noquote\"><div dir=\"ltr\">&nbsp;</div></div>") << false << 1;
+    QTest::newRow("simplespace") << u" "_s << u"<div class=\"noquote\"><div dir=\"ltr\">&nbsp;</div></div>"_s << false << 1;
     QTest::newRow("multispace")
-        << QStringLiteral("            Bug ID: 358324")
+        << u"            Bug ID: 358324"_s
         << QStringLiteral(
                "<div class=\"noquote\"><div dir=\"ltr\">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Bug ID: 358324</div></div>")
         << false << 1;
 
     QTest::newRow("bug-369072")
-        << QStringLiteral("test\n>quote1\n>>quote2\n>>>quote3\n>>new quote2\n>new quote1\nnew text")
+        << u"test\n>quote1\n>>quote2\n>>>quote3\n>>new quote2\n>new quote1\nnew text"_s
         << QStringLiteral(
                "<div class=\"noquote\"><div dir=\"ltr\">test</div>"
                "</div><blockquote><div class=\"quotelevel1\"><div dir=\"ltr\"><span class=\"quotemarks\">></span><font color=\"#008000\">quote1</font></div>"
@@ -152,17 +154,17 @@ void QuoteHtmlTest::testQuoteHtml_data()
         << false << 1;
 
     // Show Expand Quotes
-    QTest::newRow("simpletext-expand") << QStringLiteral("http") << QStringLiteral("<div class=\"noquote\"><div dir=\"ltr\">http</div></div>") << true << 1;
+    QTest::newRow("simpletext-expand") << u"http"_s << u"<div class=\"noquote\"><div dir=\"ltr\">http</div></div>"_s << true << 1;
 
     QString result = QStringLiteral(
                          "<blockquote><div class=\"quotelevelmark\" ><a href=\"kmail:levelquote?0 \"><img src=\"%1\"/></a></div><div "
                          "class=\"quotelevel1\"><div dir=\"ltr\"><span class=\"quotemarksemptyline\">></span></div></div></blockquote>")
                          .arg(mCollapseIcon);
-    QTest::newRow("simplequote-expand") << QStringLiteral(">") << result << true << 1;
-    QTest::newRow("simplespace-expand") << QStringLiteral(" ") << QStringLiteral("<div class=\"noquote\"><div dir=\"ltr\">&nbsp;</div></div>") << true << 1;
+    QTest::newRow("simplequote-expand") << u">"_s << result << true << 1;
+    QTest::newRow("simplespace-expand") << u" "_s << u"<div class=\"noquote\"><div dir=\"ltr\">&nbsp;</div></div>"_s << true << 1;
 
     QTest::newRow("bug-369072-expand-quotelevel3")
-        << QStringLiteral("test\n>quote1\n>>quote2\n>>>quote3\n>>new quote2\n>new quote1\nnew text")
+        << u"test\n>quote1\n>>quote2\n>>>quote3\n>>new quote2\n>new quote1\nnew text"_s
         << QStringLiteral(
                "<div class=\"noquote\"><div dir=\"ltr\">test</div>"
                "</div><blockquote><div class=\"quotelevelmark\" ><a href=\"kmail:levelquote?0 \"><img src=\"%1\"/></a></div>"
@@ -183,7 +185,7 @@ void QuoteHtmlTest::testQuoteHtml_data()
         << true << 3;
 
     QTest::newRow("bug-369072-expand-quotelevel2")
-        << QStringLiteral("test\n>quote1\n>>quote2\n>>>quote3\n>>new quote2\n>new quote1\nnew text")
+        << u"test\n>quote1\n>>quote2\n>>>quote3\n>>new quote2\n>new quote1\nnew text"_s
         << QStringLiteral(
                "<div class=\"noquote\"><div dir=\"ltr\">test</div></div><blockquote><div class=\"quotelevelmark\" ><a href=\"kmail:levelquote?0 \"><img "
                "src=\"%1\"/></a></div>"
@@ -201,7 +203,7 @@ void QuoteHtmlTest::testQuoteHtml_data()
         << true << 2;
 
     QTest::newRow("bug-369072-expand-quotelevel1")
-        << QStringLiteral("test\n>quote1\n>>quote2\n>>>quote3\n>>new quote2\n>new quote1\nnew text")
+        << u"test\n>quote1\n>>quote2\n>>>quote3\n>>new quote2\n>new quote1\nnew text"_s
         << QStringLiteral(
                "<div class=\"noquote\"><div dir=\"ltr\">test</div></div><blockquote><div class=\"quotelevelmark\" ><a href=\"kmail:levelquote?0 \"><img "
                "src=\"%1\"/></a></div>"
@@ -215,7 +217,7 @@ void QuoteHtmlTest::testQuoteHtml_data()
         << true << 1;
 
     QTest::newRow("bug-370452")
-        << QStringLiteral("test\n> blo\n>\n>\n>\n> bla\nnew text")
+        << u"test\n> blo\n>\n>\n>\n> bla\nnew text"_s
         << QStringLiteral(
                "<div class=\"noquote\">"
                "<div dir=\"ltr\">test</div></div>"
