@@ -4,8 +4,7 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef MIMETREEPARSER_BODYFORAMATTER_APPLICATIONPGPENCRYPTED_H
-#define MIMETREEPARSER_BODYFORAMATTER_APPLICATIONPGPENCRYPTED_H
+#pragma once
 
 #include "interfaces/bodypart.h"
 #include "interfaces/bodypartformatter.h"
@@ -17,9 +16,7 @@ class ApplicationPGPEncryptedBodyPartFormatter : public Interface::BodyPartForma
     static const ApplicationPGPEncryptedBodyPartFormatter *self;
 
 public:
-    MessagePartPtr process(Interface::BodyPart &part) const override;
+    [[nodiscard]] MessagePartPtr process(Interface::BodyPart &part) const override;
     static const Interface::BodyPartFormatter *create();
 };
 }
-
-#endif
