@@ -5,6 +5,7 @@
 */
 
 #include "templatescommandmenu.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include "templateparser_debug.h"
 #include <KActionMenu>
@@ -297,211 +298,211 @@ void TemplatesCommandMenu::slotInsertCommand(TemplatesCommandMenu::Command cmd)
 
     switch (cmd) {
     case TemplatesCommandMenu::CBlank:
-        Q_EMIT insertCommand(QStringLiteral("%BLANK"));
+        Q_EMIT insertCommand(u"%BLANK"_s);
         return;
     case TemplatesCommandMenu::CQuote:
-        Q_EMIT insertCommand(QStringLiteral("%QUOTE"));
+        Q_EMIT insertCommand(u"%QUOTE"_s);
         return;
     case TemplatesCommandMenu::CText:
-        Q_EMIT insertCommand(QStringLiteral("%TEXT"));
+        Q_EMIT insertCommand(u"%TEXT"_s);
         return;
     case TemplatesCommandMenu::COMsgId:
-        Q_EMIT insertCommand(QStringLiteral("%OMSGID"));
+        Q_EMIT insertCommand(u"%OMSGID"_s);
         return;
     case TemplatesCommandMenu::CODate:
-        Q_EMIT insertCommand(QStringLiteral("%ODATE"));
+        Q_EMIT insertCommand(u"%ODATE"_s);
         return;
     case TemplatesCommandMenu::CODateShort:
-        Q_EMIT insertCommand(QStringLiteral("%ODATESHORT"));
+        Q_EMIT insertCommand(u"%ODATESHORT"_s);
         return;
     case TemplatesCommandMenu::CODateEn:
-        Q_EMIT insertCommand(QStringLiteral("%ODATEEN"));
+        Q_EMIT insertCommand(u"%ODATEEN"_s);
         return;
     case TemplatesCommandMenu::CODow:
-        Q_EMIT insertCommand(QStringLiteral("%ODOW"));
+        Q_EMIT insertCommand(u"%ODOW"_s);
         return;
     case TemplatesCommandMenu::COTime:
-        Q_EMIT insertCommand(QStringLiteral("%OTIME"));
+        Q_EMIT insertCommand(u"%OTIME"_s);
         return;
     case TemplatesCommandMenu::COTimeLong:
-        Q_EMIT insertCommand(QStringLiteral("%OTIMELONG"));
+        Q_EMIT insertCommand(u"%OTIMELONG"_s);
         return;
     case TemplatesCommandMenu::COTimeLongEn:
-        Q_EMIT insertCommand(QStringLiteral("%OTIMELONGEN"));
+        Q_EMIT insertCommand(u"%OTIMELONGEN"_s);
         return;
     case TemplatesCommandMenu::COToAddr:
-        Q_EMIT insertCommand(QStringLiteral("%OTOADDR"));
+        Q_EMIT insertCommand(u"%OTOADDR"_s);
         return;
     case TemplatesCommandMenu::COToName:
-        Q_EMIT insertCommand(QStringLiteral("%OTONAME"));
+        Q_EMIT insertCommand(u"%OTONAME"_s);
         return;
     case TemplatesCommandMenu::COToFName:
-        Q_EMIT insertCommand(QStringLiteral("%OTOFNAME"));
+        Q_EMIT insertCommand(u"%OTOFNAME"_s);
         return;
     case TemplatesCommandMenu::COToLName:
-        Q_EMIT insertCommand(QStringLiteral("%OTOLNAME"));
+        Q_EMIT insertCommand(u"%OTOLNAME"_s);
         return;
     case TemplatesCommandMenu::COCCAddr:
-        Q_EMIT insertCommand(QStringLiteral("%OCCADDR"));
+        Q_EMIT insertCommand(u"%OCCADDR"_s);
         return;
     case TemplatesCommandMenu::COCCName:
-        Q_EMIT insertCommand(QStringLiteral("%OCCNAME"));
+        Q_EMIT insertCommand(u"%OCCNAME"_s);
         return;
     case TemplatesCommandMenu::COCCFName:
-        Q_EMIT insertCommand(QStringLiteral("%OCCFNAME"));
+        Q_EMIT insertCommand(u"%OCCFNAME"_s);
         return;
     case TemplatesCommandMenu::COCCLName:
-        Q_EMIT insertCommand(QStringLiteral("%OCCLNAME"));
+        Q_EMIT insertCommand(u"%OCCLNAME"_s);
         return;
     case TemplatesCommandMenu::COFromAddr:
-        Q_EMIT insertCommand(QStringLiteral("%OFROMADDR"));
+        Q_EMIT insertCommand(u"%OFROMADDR"_s);
         return;
     case TemplatesCommandMenu::COFromName:
-        Q_EMIT insertCommand(QStringLiteral("%OFROMNAME"));
+        Q_EMIT insertCommand(u"%OFROMNAME"_s);
         return;
     case TemplatesCommandMenu::COFromFName:
-        Q_EMIT insertCommand(QStringLiteral("%OFROMFNAME"));
+        Q_EMIT insertCommand(u"%OFROMFNAME"_s);
         return;
     case TemplatesCommandMenu::COFromLName:
-        Q_EMIT insertCommand(QStringLiteral("%OFROMLNAME"));
+        Q_EMIT insertCommand(u"%OFROMLNAME"_s);
         return;
     case TemplatesCommandMenu::COFullSubject:
-        Q_EMIT insertCommand(QStringLiteral("%OFULLSUBJECT"));
+        Q_EMIT insertCommand(u"%OFULLSUBJECT"_s);
         return;
     case TemplatesCommandMenu::CQHeaders:
-        Q_EMIT insertCommand(QStringLiteral("%QHEADERS"));
+        Q_EMIT insertCommand(u"%QHEADERS"_s);
         return;
     case TemplatesCommandMenu::CHeaders:
-        Q_EMIT insertCommand(QStringLiteral("%HEADERS"));
+        Q_EMIT insertCommand(u"%HEADERS"_s);
         return;
     case TemplatesCommandMenu::COHeader:
-        Q_EMIT insertCommand(QStringLiteral("%OHEADER=\"\""), -1);
+        Q_EMIT insertCommand(u"%OHEADER=\"\""_s, -1);
         return;
     case TemplatesCommandMenu::CMsgId:
-        Q_EMIT insertCommand(QStringLiteral("%MSGID"));
+        Q_EMIT insertCommand(u"%MSGID"_s);
         return;
     case TemplatesCommandMenu::CDate:
-        Q_EMIT insertCommand(QStringLiteral("%DATE"));
+        Q_EMIT insertCommand(u"%DATE"_s);
         return;
     case TemplatesCommandMenu::CDateShort:
-        Q_EMIT insertCommand(QStringLiteral("%DATESHORT"));
+        Q_EMIT insertCommand(u"%DATESHORT"_s);
         return;
     case TemplatesCommandMenu::CDateEn:
-        Q_EMIT insertCommand(QStringLiteral("%DATEEN"));
+        Q_EMIT insertCommand(u"%DATEEN"_s);
         return;
     case TemplatesCommandMenu::CDow:
-        Q_EMIT insertCommand(QStringLiteral("%DOW"));
+        Q_EMIT insertCommand(u"%DOW"_s);
         return;
     case TemplatesCommandMenu::CTime:
-        Q_EMIT insertCommand(QStringLiteral("%TIME"));
+        Q_EMIT insertCommand(u"%TIME"_s);
         return;
     case TemplatesCommandMenu::CTimeLong:
-        Q_EMIT insertCommand(QStringLiteral("%TIMELONG"));
+        Q_EMIT insertCommand(u"%TIMELONG"_s);
         return;
     case TemplatesCommandMenu::CTimeLongEn:
-        Q_EMIT insertCommand(QStringLiteral("%TIMELONGEN"));
+        Q_EMIT insertCommand(u"%TIMELONGEN"_s);
         return;
     case TemplatesCommandMenu::COAddresseesAddr:
-        Q_EMIT insertCommand(QStringLiteral("%OADDRESSEESADDR"));
+        Q_EMIT insertCommand(u"%OADDRESSEESADDR"_s);
         return;
     case TemplatesCommandMenu::CToAddr:
-        Q_EMIT insertCommand(QStringLiteral("%TOADDR"));
+        Q_EMIT insertCommand(u"%TOADDR"_s);
         return;
     case TemplatesCommandMenu::CToName:
-        Q_EMIT insertCommand(QStringLiteral("%TONAME"));
+        Q_EMIT insertCommand(u"%TONAME"_s);
         return;
     case TemplatesCommandMenu::CToFName:
-        Q_EMIT insertCommand(QStringLiteral("%TOFNAME"));
+        Q_EMIT insertCommand(u"%TOFNAME"_s);
         return;
     case TemplatesCommandMenu::CToLName:
-        Q_EMIT insertCommand(QStringLiteral("%TOLNAME"));
+        Q_EMIT insertCommand(u"%TOLNAME"_s);
         return;
     case TemplatesCommandMenu::CCCAddr:
-        Q_EMIT insertCommand(QStringLiteral("%CCADDR"));
+        Q_EMIT insertCommand(u"%CCADDR"_s);
         return;
     case TemplatesCommandMenu::CCCName:
-        Q_EMIT insertCommand(QStringLiteral("%CCNAME"));
+        Q_EMIT insertCommand(u"%CCNAME"_s);
         return;
     case TemplatesCommandMenu::CCCFName:
-        Q_EMIT insertCommand(QStringLiteral("%CCFNAME"));
+        Q_EMIT insertCommand(u"%CCFNAME"_s);
         return;
     case TemplatesCommandMenu::CCCLName:
-        Q_EMIT insertCommand(QStringLiteral("%CCLNAME"));
+        Q_EMIT insertCommand(u"%CCLNAME"_s);
         return;
     case TemplatesCommandMenu::CFromAddr:
-        Q_EMIT insertCommand(QStringLiteral("%FROMADDR"));
+        Q_EMIT insertCommand(u"%FROMADDR"_s);
         return;
     case TemplatesCommandMenu::CFromName:
-        Q_EMIT insertCommand(QStringLiteral("%FROMNAME"));
+        Q_EMIT insertCommand(u"%FROMNAME"_s);
         return;
     case TemplatesCommandMenu::CFromFName:
-        Q_EMIT insertCommand(QStringLiteral("%FROMFNAME"));
+        Q_EMIT insertCommand(u"%FROMFNAME"_s);
         return;
     case TemplatesCommandMenu::CFromLName:
-        Q_EMIT insertCommand(QStringLiteral("%FROMLNAME"));
+        Q_EMIT insertCommand(u"%FROMLNAME"_s);
         return;
     case TemplatesCommandMenu::CFullSubject:
-        Q_EMIT insertCommand(QStringLiteral("%FULLSUBJECT"));
+        Q_EMIT insertCommand(u"%FULLSUBJECT"_s);
         return;
     case TemplatesCommandMenu::CHeader:
-        Q_EMIT insertCommand(QStringLiteral("%HEADER=\"\""), -1);
+        Q_EMIT insertCommand(u"%HEADER=\"\""_s, -1);
         return;
     case TemplatesCommandMenu::CSystem:
-        Q_EMIT insertCommand(QStringLiteral("%SYSTEM=\"\""), -1);
+        Q_EMIT insertCommand(u"%SYSTEM=\"\""_s, -1);
         return;
     case TemplatesCommandMenu::CQuotePipe:
-        Q_EMIT insertCommand(QStringLiteral("%QUOTEPIPE=\"\""), -1);
+        Q_EMIT insertCommand(u"%QUOTEPIPE=\"\""_s, -1);
         return;
     case TemplatesCommandMenu::CTextPipe:
-        Q_EMIT insertCommand(QStringLiteral("%TEXTPIPE=\"\""), -1);
+        Q_EMIT insertCommand(u"%TEXTPIPE=\"\""_s, -1);
         return;
     case TemplatesCommandMenu::CMsgPipe:
-        Q_EMIT insertCommand(QStringLiteral("%MSGPIPE=\"\""), -1);
+        Q_EMIT insertCommand(u"%MSGPIPE=\"\""_s, -1);
         return;
     case TemplatesCommandMenu::CBodyPipe:
-        Q_EMIT insertCommand(QStringLiteral("%BODYPIPE=\"\""), -1);
+        Q_EMIT insertCommand(u"%BODYPIPE=\"\""_s, -1);
         return;
     case TemplatesCommandMenu::CClearPipe:
-        Q_EMIT insertCommand(QStringLiteral("%CLEARPIPE=\"\""), -1);
+        Q_EMIT insertCommand(u"%CLEARPIPE=\"\""_s, -1);
         return;
     case TemplatesCommandMenu::CCursor:
-        Q_EMIT insertCommand(QStringLiteral("%CURSOR"));
+        Q_EMIT insertCommand(u"%CURSOR"_s);
         return;
     case TemplatesCommandMenu::CSignature:
-        Q_EMIT insertCommand(QStringLiteral("%SIGNATURE"));
+        Q_EMIT insertCommand(u"%SIGNATURE"_s);
         return;
     case TemplatesCommandMenu::CInsert:
-        Q_EMIT insertCommand(QStringLiteral("%INSERT=\"\""), -1);
+        Q_EMIT insertCommand(u"%INSERT=\"\""_s, -1);
         return;
     case TemplatesCommandMenu::CDnl:
-        Q_EMIT insertCommand(QStringLiteral("%-"));
+        Q_EMIT insertCommand(u"%-"_s);
         return;
     case TemplatesCommandMenu::CRem:
-        Q_EMIT insertCommand(QStringLiteral("%REM=\"\""), -1);
+        Q_EMIT insertCommand(u"%REM=\"\""_s, -1);
         return;
     case TemplatesCommandMenu::CNop:
-        Q_EMIT insertCommand(QStringLiteral("%NOP"));
+        Q_EMIT insertCommand(u"%NOP"_s);
         return;
     case TemplatesCommandMenu::CClear:
-        Q_EMIT insertCommand(QStringLiteral("%CLEAR"));
+        Q_EMIT insertCommand(u"%CLEAR"_s);
         return;
     case TemplatesCommandMenu::CDebug:
-        Q_EMIT insertCommand(QStringLiteral("%DEBUG"));
+        Q_EMIT insertCommand(u"%DEBUG"_s);
         return;
     case TemplatesCommandMenu::CDebugOff:
-        Q_EMIT insertCommand(QStringLiteral("%DEBUGOFF"));
+        Q_EMIT insertCommand(u"%DEBUGOFF"_s);
         return;
     case TemplatesCommandMenu::CQuotePlain:
-        Q_EMIT insertCommand(QStringLiteral("%FORCEDPLAIN"));
+        Q_EMIT insertCommand(u"%FORCEDPLAIN"_s);
         return;
     case TemplatesCommandMenu::CQuoteHtml:
-        Q_EMIT insertCommand(QStringLiteral("%FORCEDHTML"));
+        Q_EMIT insertCommand(u"%FORCEDHTML"_s);
         return;
     case TemplatesCommandMenu::CDictionaryLanguage:
-        Q_EMIT insertCommand(QStringLiteral("%DICTIONARYLANGUAGE=\"\""), -1);
+        Q_EMIT insertCommand(u"%DICTIONARYLANGUAGE=\"\""_s, -1);
         return;
     case TemplatesCommandMenu::CLanguage:
-        Q_EMIT insertCommand(QStringLiteral("%LANGUAGE=\"\""), -1);
+        Q_EMIT insertCommand(u"%LANGUAGE=\"\""_s, -1);
         return;
     }
     qCDebug(TEMPLATEPARSER_LOG) << "Unknown template command index:" << cmd;
